@@ -34,11 +34,9 @@ zad.est <- function(y) {
   ##############
   ini.par <- c( log(ini.phi), as.vector( t( beta.ini) ) )  ## initial parameter values
   z <- list(ly1 = ly1, ly2 = ly2, x1 = x1, x2 = x2, a1 = a1, a2 = a2)
-  oop <- options( warn = -1 )
-  on.exit( options(oop) )
   suppressWarnings({
-  qa <- optim( ini.par, mixreg, z = z, hessian = TRUE, control = list(maxit = 10000) )
-  qa <- optim( qa$par, mixreg, z = z, hessian = TRUE, control = list(maxit = 10000) )
+    qa <- optim( ini.par, .mixreg, z = z, hessian = TRUE, control = list(maxit = 10000) )
+    qa <- optim( qa$par, .mixreg, z = z, hessian = TRUE, control = list(maxit = 10000) )
   })
   phi <- exp( qa$par[1] )  ## final phi value
   mu <- c(1, exp(qa$par[-1]) ) ## final beta values
